#[non_exhaustive]pub struct CloudConfig {
pub org: Option<String>,
pub api_url: String,
pub pipeline: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.org: Option<String>api_url: Stringpipeline: Option<String>Org-global pipeline slug to submit builds to directly (set by hm run
after registering a remoteless directory). When present, cloud runs
submit by this slug instead of resolving by git-repo identity.